translate.convert.json2po

Package translate :: Package convert :: Module json2po |
[hide private]
[frames] | no frames]

# Module json2po

source code

Convert JSON files to Gettext PO localization files

Classes | [hide private]
| json2po Convert a JSON file to a PO file

Functions | [hide private]
convertjson(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt", dialect="default", filter=None) Reads in `input_file` using jsonl10n, converts using json2po, writes to `output_file` | source code
main(argv=None) | source code

Imports: sys, po